/*--------------------------------------------------------------------------+
$Id: ElementTreeMultiSelectDialog.java 5186 2012-07-27 20:23:37Z ratiu $
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import java.util.List;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;

/**
 * This dialog offers a question dialog with different button label
 * 
 * @author wenwenchen
 * @author $Author: ratiu $
 * @version $Rev: 5186 $
 * @ConQAT.Rating GREEN Hash: E835C665671D57B2619E28232ABFC1F7
 */
public class ButtonDialog extends Dialog {

	/** The title of the dialog. */
	private String title;

	/** The message to display, or <code>null</code> if none. */
	private String message;

	/** roots of the tree */
	private List<String> buttonNames;

	/** The gui composite */
	private ButtonDialogGUI gui;

	/** Number of selected button */
	private int selection;

	/** Constructor. */
	public ButtonDialog(Shell parentShell, String dialogTitle, String dialogMessage,
			List<String> buttonNames) {
		super(parentShell);
		this.title = dialogTitle;
		this.message = dialogMessage;
		this.buttonNames = buttonNames;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.window.Window#configureShell(org.eclipse.swt.widgets.Shell)
	 */
	/** {@inheritDoc} */
	@Override
	protected void configureShell(Shell shell) {
		super.configureShell(shell);
		if(title != null) {
			shell.setText(title);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.jface.dialogs.Dialog#createButtonsForButtonBar(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	protected void createButtonsForButtonBar(Composite parent) {
		// create Cancel buttons by default
		createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CANCEL_LABEL, false);
	}

	/** {@inheritDoc} */
	@Override
	protected Control createDialogArea(Composite parent) {
		// create composite
		Composite composite = (Composite)super.createDialogArea(parent);
		// create message
		if(message != null) {
			Label label = new Label(composite, SWT.WRAP);
			label.setText(message);
			GridData data =
					new GridData(GridData.GRAB_HORIZONTAL | GridData.GRAB_VERTICAL |
							GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_CENTER);
			data.widthHint =
					convertHorizontalDLUsToPixels(IDialogConstants.MINIMUM_MESSAGE_AREA_WIDTH);
			label.setLayoutData(data);
			label.setFont(parent.getFont());
		}

		gui = new ButtonDialogGUI(composite, SWT.NONE, buttonNames);
		gui.setLayoutData(new GridData(GridData.FILL_BOTH));

		for(final Button button : gui.getButtons()) {
			button.addSelectionListener(new SelectionAdapter() {
				/** {@inheritDoc} */
				@Override
				public void widgetSelected(SelectionEvent e) {
					selection = gui.getButtons().indexOf(button);
					okPressed();
				}
			});
		}
		applyDialogFont(composite);
		return composite;
	}

	/**
	 * Returns the pressed button number.
	 * 
	 * @return the pressed button number
	 */
	public int getSelection() {
		return selection;
	}
}
