/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.command;

import java.util.List;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.editpart.ElementEditPartBase;
import org.fortiss.tooling.base.ui.editpart.FreeConnectorEditPartBase;
import org.fortiss.tooling.base.ui.utils.LayoutDataUIUtils;

/**
 * A command to move the elements and free connectors within a diagram.
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 6F8323B7B7FCC23CA5D6C64D320C47D6
 */
public class MoveWithinDiagramCommand extends ChangeBoundsRequestCommandBase {

	/** Constructor. */
	public MoveWithinDiagramCommand(ChangeBoundsRequest request) {
		super(request);
	}

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public void execute() {
		LayoutDataUIUtils.bendpointGroupMove(request.getEditParts(), request.getMoveDelta().x,
				request.getMoveDelta().y);

		for(EditPart editpart : (List<EditPart>)getRequest().getEditParts()) {
			if(editpart instanceof ElementEditPartBase) {
				ElementEditPartBase<? extends ILayoutedModelElement> elementEditPart =
						(ElementEditPartBase<? extends ILayoutedModelElement>)editpart;
				elementEditPart.getLayoutConfiguration().performElementMoveAndResize(
						elementEditPart, request);
			} else if(editpart instanceof FreeConnectorEditPartBase) {
				FreeConnectorEditPartBase<? extends ILayoutedModelElement> connectorEditPart =
						(FreeConnectorEditPartBase<? extends ILayoutedModelElement>)editpart;
				connectorEditPart.getLayoutConfiguration().performFreeConnectorMove(
						connectorEditPart, request);
			}
		}
	}
}
