/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import org.fortiss.tooling.base.layout.DefaultLayoutConstants;
import org.fortiss.tooling.base.model.layout.Point;

/**
 * Utility methods for snap-to-grid support.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: EF992553C0789E0F4F575D5217D7CF68
 */
public final class SnapToGridUtils {

	/** Returns the given value aligned to the given grid size. */
	public static int snapToGrid(double d, int gridSize) {
		return gridSize * (int)Math.round(d / gridSize);
	}

	/** Returns the given value aligned to the recommended grid size. */
	public static int snapToGrid(double d) {
		return snapToGrid(d, DefaultLayoutConstants.DEFAULT_GRID_SIZE);
	}

	/**
	 * Modifies the x and y coordinates of the given point to be on the grid of
	 * the given size.
	 */
	public static void snapToGrid(Point p, int gridSize) {
		p.setX(snapToGrid(p.getX(), gridSize));
		p.setY(snapToGrid(p.getY(), gridSize));
	}

	/** Modifies the x and y coordinates of the given point to be on the grid. */
	public static void snapToGrid(Point p) {
		p.setX(snapToGrid(p.getX(), DefaultLayoutConstants.DEFAULT_GRID_SIZE));
		p.setY(snapToGrid(p.getY(), DefaultLayoutConstants.DEFAULT_GRID_SIZE));
	}
}
