/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.draw;

import static org.eclipse.ui.PlatformUI.getWorkbench;

/**
 * Thread class for the render thread with a default sleep period of 40ms (i.e. about 25fps).
 * The thread executes a refresh of the canvas using a Display async execution and dies as soon as
 * the canvas is disposed. Note that the refresh is only performed if the canvas is not disposed and
 * is visible.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: EC035BA669B676BD379E9BF40EA4A006
 */
public class LwjglRenderThread extends Thread {

	/** The GLCanvas to be rendered by this thread. */
	private final LwjglCanvas canvas;

	/** The render thread sleep period. */
	private int sleepPeriod = 40;

	/** The content renderer runnable. */
	private final Runnable contentRenderer;

	/** Constructor. */
	public LwjglRenderThread(LwjglCanvas canvas, Runnable contentRenderer) {
		if(canvas == null) {
			throw new IllegalArgumentException("Canvas may not be null.");
		}
		if(contentRenderer == null) {
			throw new IllegalArgumentException("Content render may not be null.");
		}
		this.canvas = canvas;
		this.contentRenderer = contentRenderer;
	}

	/** Sets the sleep period of the render thread in milliseconds. */
	public void setSleepPeriod(int sleepPeriod) {
		this.sleepPeriod = sleepPeriod;
	}

	/** {@inheritDoc} */
	@Override
	public void run() {
		try {
			sleep(sleepPeriod);
			while(!canvas.isDisposed()) {
				getWorkbench().getDisplay().asyncExec(refresher);
				sleep(sleepPeriod);
			}
		} catch(InterruptedException e) {
			e.printStackTrace();
		}
	}

	/** The refresher display runner. */
	private Runnable refresher = new Runnable() {
		@Override
		public void run() {
			if(!canvas.isDisposed() && canvas.isVisible()) {
				canvas.setCurrentAndUseContext();
				contentRenderer.run();
				canvas.swapBuffers();
			}
		}
	};
}
