/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.extension;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.model.constraints.IConstraint;
import org.fortiss.tooling.kernel.model.constraints.IConstraintVerificationStatus;
import org.fortiss.tooling.kernel.service.base.IEObjectAware;

/**
 * Interface for the GUI of constraint verifiers.
 * 
 * @author aravantinos
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 55841F342D5CE5159A902AB923946C35
 */
public interface IConstraintVerifierUI<T extends IConstraint> extends IEObjectAware<T> {

	/**
	 * Action to take when trying to open the given status. <code>canOpen</code> should be called
	 * before to know if the status can be opened.
	 * 
	 * @return true if the status could indeed be open, false if it needs further handling.
	 */
	public boolean openStatus(IConstraintVerificationStatus status);

	/** True if the given status can be open. */
	public boolean canOpen(IConstraintVerificationStatus status);

	/** Method to execute when a constraint gets outdated. */
	public void onOutdate(T constraint);

	/**
	 * @param status
	 * @return a short user-friendly description explaining the status.
	 */
	public String getMessage(IConstraintVerificationStatus status);

	/**
	 * The following features deal with the usage of constraints to drive the process.
	 * 
	 * EXPERIMENTAL.
	 */

	/** Activates the constraint type. */
	public void activate(EObject context);

	/** Deactivates the constraint type. */
	public void deactivate(EObject context);

	/**
	 * ID of the constraint. Must be unique among all constraints which are usable for development
	 * process. *Must match* the ID of the corresponding constraint non-UI verifier.
	 */
	public String getID();
}
