package org.fortiss.tooling.kernel.ui.service;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.model.constraints.IConstraint;
import org.fortiss.tooling.kernel.model.constraints.IConstraintVerificationStatus;
import org.fortiss.tooling.kernel.service.IConstraintVerificationService;
import org.fortiss.tooling.kernel.ui.extension.IConstraintVerifierUI;
import org.fortiss.tooling.kernel.ui.internal.ConstraintVerificationUIService;

/**
 * GUI aspects of {@link IConstraintVerificationService}.
 * 
 * @author aravantinos
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 7219766068C024D972B4871A0891118D
 */
public interface IConstraintVerificationUIService {
	/** Returns the service instance. */
	public static IConstraintVerificationUIService getInstance() {
		return ConstraintVerificationUIService.getInstance();
	}

	/** Action to take when trying to open the given status. */
	void openStatus(IConstraintVerificationStatus status);

	/** True if the given status can be open. */
	boolean canOpen(IConstraintVerificationStatus status);

	/** Install the given constraint: install notifiers and triggers an "onOutdate" event. */
	void install(IConstraint constraint);

	/** Registers the verifier UI part with the kernel. */
	<T extends IConstraint> void registerConstraintVerifierUI(IConstraintVerifierUI<T> verifier,
			Class<T> constraintElementClass);

	/**
	 * The following features deal with the usage of constraints to drive the process.
	 * 
	 * EXPERIMENTAL.
	 */

	/** Activates the constraint type. */
	<T extends IConstraint> void activate(String id, EObject context);

	/** Deactivates the constraint type. */
	<T extends IConstraint> void deactivate(String id, EObject context);
}
