/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import org.fortiss.tooling.kernel.service.ILoggingService;

/**
 * Base class for all messages that can be emitted to the {@link ILoggingService}. This simple
 * base class just wraps a String, but more sophisticated {@link LogMessage} can be implemented via
 * inheritance.
 * 
 * @author diewald
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 2458C952A5383F445F9B533E4866A1C9
 */
public class LogMessage {
	/** The message String transported my this {@link LogMessage}. */
	protected final String messageString;

	/**
	 * Constructor.
	 * 
	 * @param messageString
	 *            message string that is transported by this {@link LogMessage}.
	 */
	public LogMessage(String messageString) {
		this.messageString = messageString;
	}

	/** Returns the transported message String. */
	public final String getMessage() {
		return messageString;
	}
}
