/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.fortiss.tooling.kernel.extension.ITutorialProvider;
import org.fortiss.tooling.kernel.extension.ITutorialWhitelistProvider;
import org.fortiss.tooling.kernel.extension.data.TutorialAtomicStep;
import org.fortiss.tooling.kernel.extension.data.TutorialStepBase;
import org.fortiss.tooling.kernel.internal.TutorialService;
import org.fortiss.tooling.kernel.service.listener.ITutorialServiceListener;

/**
 * The tutorial service provides pre-defined models with step-wise
 * example procedures for implementing educational tutorials to
 * the end-user.
 * <P>
 * This interface extends {@link ITutorialWhitelistProvider}, which delegates its method calls to
 * the current {@link ITutorialProvider}'s global whitelist provider and the current
 * {@link TutorialStepBase}'s local whitelist provider. Note that those methods <B>MUST NOT</B> be
 * called unless {@link #isTutorialActive()} returns <code>true</code>.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: 57990CE5047853728187501DBAB36C9A
 */
public interface ITutorialService extends ITutorialWhitelistProvider {
	/** Returns the service instance. */
	public static ITutorialService getInstance() {
		return TutorialService.getInstance();
	}

	/** Returns whether any tutorial is currently enabled. */
	boolean isTutorialActive();

	/** Returns the current tutorial definition or <code>null</code> if no tutorial is active. */
	ITutorialProvider getActiveTutorial();

	/**
	 * Returns the list of all atomic tutorial steps, i.e., a flattening of the hierarchical
	 * tutorial definition.
	 */
	List<TutorialAtomicStep> getAtomicTutorialSteps();

	/** Starts the given tutorial. */
	void startTutorial(Class<? extends ITutorialProvider> provider);

	/** Stops the current tutorial. */
	void stopTutorial();

	/** Returns the active tutorial step. */
	TutorialStepBase getActiveTutorialStep();

	/** Returns whether the given step is completed. */
	boolean isCompletedStep(TutorialStepBase step);

	/** Returns all registered tutorial providers for the given category. */
	Map<String, Class<? extends ITutorialProvider>> getAllTutorialProviders(String category);

	/** Returns all category names, which have at least one provider. */
	Collection<String> getProviderCategories();

	/** Programmatically register a tutorial provider. */
	void registerTutorialProvider(Class<? extends ITutorialProvider> provider, String displayName,
			String category);

	/** Adds a listener with this service. */
	void addTutorialServiceListener(ITutorialServiceListener l);

	/** Removes a listener from this service. */
	void removeTutorialServiceListener(ITutorialServiceListener l);
}
