/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.model;

import static java.util.Collections.sort;

import java.util.Comparator;
import java.util.List;

/**
 * An axis that represents an enumeration.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: EF67711684D1153304B0C6352B92ACBA
 */
public final class EnumerationAxis<T extends Object> extends AxisBase {

	/** The enumeration values of this axis. */
	private final List<T> values;

	/** Constructor. */
	public EnumerationAxis(String name, Comparator<T> comparator, List<T> values) {
		super(name);
		this.values = values;
		sort(this.values, comparator);
	}

	/** Returns the member at the given index. */
	public T getEnumerationMemberAtIndex(int index) {
		if(index >= 0 && index < values.size()) {
			return values.get(index);
		}
		return null;
	}

	/** Returns the index of the given member. */
	public int indexOfEnumerationMember(T member) {
		return values.indexOf(member);
	}

	/** {@inheritDoc} */
	@Override
	public boolean isValidValue(Object d) {
		return values.contains(d);
	}
}
