/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.widget;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.events.ControlListener;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.spiderchart.model.SpiderChart;
import org.fortiss.tooling.spiderchart.style.ChartStyle;

/**
 * Represents a viewer on the canvas to display the spider chart.
 *
 * @author mondal
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: E1157244DA86EA45049BE0E887E427C4
 */
public final class SpiderChartViewer extends Composite implements MouseListener {
	/** The actual canvas to be used for drawing. */
	private final SpiderChartSWTCanvas canvas;

	/** Constructor */
	public SpiderChartViewer(Composite parent, SpiderChart chart, ChartStyle style) {
		super(parent, SWT.NONE);

		canvas = new SpiderChartSWTCanvas(this, chart, style);
		canvas.addMouseListener(this);

		addControlListener(new ControlListener() {
			@Override
			public void controlMoved(ControlEvent e) {
				// not used
			}

			@Override
			public void controlResized(ControlEvent e) {
				Rectangle b = getBounds();
				canvas.setLocation(b.x, b.y);
				canvas.setSize(b.width, b.height);
			}
		});
	}

	/** {@inheritDoc} */
	@Override
	public boolean setFocus() {
		return canvas.setFocus();
	}

	/** Redraws the chart */
	public void redrawChart() {
		canvas.redraw();
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		canvas.dispose();
		super.dispose();
	}

	/** {@inheritDoc} */
	@Override
	public void mouseDoubleClick(MouseEvent e) {
		// nothing to do
	}

	/** {@inheritDoc} */
	@Override
	public void mouseDown(MouseEvent e) {
		// nothing to do
	}

	/** {@inheritDoc} */
	@Override
	public void mouseUp(MouseEvent e) {
		canvas.mouseClickedAt(e.x, e.y);
	}
}
